@@ -8,6 +8,7 @@ package App::PDF::Link::Icons;
 
 use Carp;
 use parent qw(Exporter);
+use App::Packager;
 
 our @EXPORT = qw( load_icon_images get_icon );
 
@@ -22,6 +23,8 @@ sub _load_icon_images {
 	html	    => 'builtin:iRealPro',
 	sib	    => 'builtin:Sibelius',
 	xml	    => 'builtin:XML',
+	mxl	    => 'builtin:MXL',
+	musicxml    => 'builtin:MXL',
 	abc	    => 'builtin:ABC',
       );
 
